@@ -218,7 +218,7 @@ func isModeLine(line []byte) bool {
 
 // --- a/internal/addrs/move_endpoint_module.go
 func isMinusFileLine(line []byte) bool {
-	if len(line) > 3 && bytes.Equal(line[:3], []byte("---")) {
+	if len(line) >= 6 && bytes.Equal(line[:3], []byte("---")) {
 		return true
 	}
 	return false
@@ -226,7 +226,7 @@ func isMinusFileLine(line []byte) bool {
 
 // +++ b/internal/addrs/move_endpoint_module.go
 func isPlusFileLine(line []byte) bool {
-	if len(line) > 3 && bytes.Equal(line[:3], []byte("+++")) {
+	if len(line) >= 6 && bytes.Equal(line[:3], []byte("+++")) {
 		return true
 	}
 	return false
