@@ -229,12 +229,12 @@ func TestSource_Chunks_Integration(t *testing.T) {
 				"2f251b8c1e72135a375b659951097ec7749d4af9-bump": {B: []byte(" \n")},
 				"e6c8bbabd8796ea3cd85bfc2e55b27e0a491747f-bump": {B: []byte("oops \n")},
 				"735b52b0eb40610002bb1088e902bd61824eb305-bump": {B: []byte("oops\n")},
-				//"ce62d79908803153ef6e145e042d3e80488ef747-bump":  {B: []byte("\n")},
+				"ce62d79908803153ef6e145e042d3e80488ef747-bump": {B: []byte("\n")},
 				// Normally we might expect to see this commit, and we may in the future.
 				// But at the moment we're ignoring any commit unless it contains at least one non-space character.
-				"27fbead3bf883cdb7de9d7825ed401f28f9398f1-slack": {B: []byte("yup, just did that\n\ngithub_lol: \"ffc7e0f9400fb6300167009e42d2f842cd7956e2\"\n\noh, goodness. there's another one!")},
-				"8afb0ecd4998b1179e428db5ebbcdc8221214432-slack": {B: []byte("oops might drop a slack token here\n\ngithub_secret=\"369963c1434c377428ca8531fbc46c0c43d037a0\"\n\nyup, just did that"), Multi: true},
-				"8fe6f04ef1839e3fc54b5147e3d0e0b7ab971bd5-aws":   {B: []byte("blah blaj\n\nthis is the secret: AKIA2E0A8F3B244C9986\n\nokay thank you bye"), Multi: true},
+				"27fbead3bf883cdb7de9d7825ed401f28f9398f1-slack": {B: []byte("yup, just did that\n\ngithub_lol: \"ffc7e0f9400fb6300167009e42d2f842cd7956e2\"\n\noh, goodness. there's another one!\n")},
+				"8afb0ecd4998b1179e428db5ebbcdc8221214432-slack": {B: []byte("oops might drop a slack token here\n\ngithub_secret=\"369963c1434c377428ca8531fbc46c0c43d037a0\"\n\nyup, just did that\n"), Multi: true},
+				"8fe6f04ef1839e3fc54b5147e3d0e0b7ab971bd5-aws":   {B: []byte("blah blaj\n\nthis is the secret: AKIA2E0A8F3B244C9986\n\nokay thank you bye\n"), Multi: true},
 				"84e9c75e388ae3e866e121087ea2dd45a71068f2-aws":   {B: []byte("this is the secret: [Default]\nAccess key Id: AKIAILE3JG6KMS3HZGCA\nSecret Access Key: 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\n"), Multi: true},
 			},
 		},
@@ -262,11 +262,10 @@ func TestSource_Chunks_Integration(t *testing.T) {
 			}()
 
 			for chunk := range chunksCh {
-
 				key := ""
 				switch meta := chunk.SourceMetadata.GetData().(type) {
 				case *source_metadatapb.MetaData_Git:
-					key = meta.Git.Commit + "-" + meta.Git.File
+					key = strings.TrimRight(meta.Git.Commit+"-"+meta.Git.File, "\n")
 				}
 
 				if expectedData, exists := tt.expectedChunkData[key]; !exists {
